#!/usr/bin/bash
#root portion of the configuration
if [[ $EUID -ne 0 ]]; then
   echo -e "Root permissions required" 1>&2
   exit 100
fi
_nc='\033[0m'
_red='\033[0;31m'
_green='\033[0;32m'
_yellow='\033[0;33m'
_blue='\033[1;34m'
_purple='\033[0;35m'
_cyan='\033[0;36m'

#halt any running instance
systemctl disable --now skywire.service
systemctl disable --now skywire-visor.service

#config generation writes in the current dir;
#so we want to make anything spawned by the process appear as a subdirectory of install dir
cd /opt/skywire/

#try to reuse old config
[[ -f /opt/skywire/skywire.json ]] && cp -b /opt/skywire/skywire.json /opt/skywire/skywire.json.gen

#generate hypervisor configuration
skywire-cli visor gen-config --is-hypervisor -p -r -o /opt/skywire/skywire.json.gen

#move it to it's location
mv /opt/skywire/skywire.json.gen /opt/skywire/skywire.json

#generate tls keys
skywire-tls-gen

if pacman -Qs hypervisorkey > /dev/null ; then  #hypervisorkey installed, start as visor
if [[ ! -f /opt/skywire/skywire-visor.json ]] ; then #no visor config, it was reset
hypervisorkey-autoconfig  #regenerate the visor config
else  #config exists
systemctl enable --now skywire-visor.service
echo
echo -e "${_blue}Skywire${_nc} has been configured!"
echo
echo -e "starting in visor-only mode"
_hvk=$(cat /opt/skywire/hypervisor.txt)
echo
echo -e "hypervisors: ${_purple}${_hvk}${_nc}"
_pubkey=$(cat /opt/skywire/skywire-visor.json | grep pk\")
_pubkey=${_pubkey#*: }
echo
echo -e "Visor Public Key: ${_green}${_pubkey}${_nc}"
echo
fi
else #hypervisorkey not installed
#start as hypervisor
systemctl enable --now skywire.service
echo
echo -e "${_blue}Skywire${_nc} has been configured!"
echo
echo -e "starting now on:
${_red}https://127.0.0.1:8000${_nc}"
_lanip=$(ifconfig | grep inet | head -n 1)
_lanip=${_lanip##*inet }
_lanip=${_lanip%% *}
echo
echo -e "Access from local network at:
${_yellow}https://${_lanip}:8000${_nc}"
_pubkey=$(cat /opt/skywire/skywire.json | grep pk\")
_pubkey=${_pubkey#*: }
echo
echo -e "Visor Public Key:
${_green}${_pubkey}${_nc}"
echo
echo -e "run ${_cyan}keypkg-gen${_nc} to generate the distributable public key package"
echo
fi
if pacman -Qs skywire-save > /dev/null ; then
echo -e "persisted configuration detected"
else
echo -e "run ${_cyan}skywire-save${_nc} to back up the current configuration!"
fi
echo
echo -e "Visit ${_blue}https://whitelist.skycoin.com/${_nc} to register your public key."
echo
